/*
 * This file is generated by objective.metadata
 *
 * Last update: Wed Jan 16 13:10:52 2013
 */
#import <CryptoTokenKit/CryptoTokenKit.h>

static void __attribute__((__used__)) use_protocols(void)
{
    PyObject* p __attribute__((__unused__));
#if PyObjC_BUILD_RELEASE >= 1011
    p = PyObjC_IdToPython(@protocol(TKSmartCardUserInteractionDelegate));
    Py_XDECREF(p);
#endif
#if PyObjC_BUILD_RELEASE >= 1012
    p = PyObjC_IdToPython(@protocol(TKSmartCardTokenDriverDelegate));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(TKTokenSessionDelegate));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(TKTokenDelegate));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(TKTokenDriverDelegate));
    Py_XDECREF(p);
#endif
}
